@@ -4,7 +4,7 @@ use base 'Perinci::Sub::Gen::AccessTable::I18N';
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -19,9 +19,23 @@ our $VERSION = '0.26'; # VERSION
 
 Perinci::Sub::Gen::AccessTable::I18N::en - English translation for Perinci::Sub::Gen::AccessTable
 
-=head1 VERSION
+=head1 HOMEPAGE
 
-version 0.26
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Gen-AccessTable>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-AccessTable>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Gen-AccessTabl
+e
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -34,13 +48,6 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =cut
 
 __DATA__
@@ -139,6 +146,11 @@ msgstr "Search"
 msgid  "Only return records where the '%1' field equals specified value"
 msgstr "Only return records where the '%1' field equals specified value"
 
+# arg: FIELD.isnt
+
+msgid  "Only return records where the '%1' field does not equal specified value"
+msgstr "Only return records where the '%1' field does not equal specified value"
+
 # arg: FIELD.in
 
 msgid  "Only return records where the '%1' field is in the specified values"
@@ -198,4 +210,3 @@ msgstr "Only return records where the '%1' field matches specified regular expre
 
 msgid  "Only return records where the '%1' field does not match specified regular expression"
 msgstr "Only return records where the '%1' field does not match specified regular expression"
-
